@@ -30,33 +30,31 @@ class Cakework(cakework_pb2_grpc.CakeworkServicer):
         self.user_activity = user_activity
         self.local = local
         if self.local:
-            self.frontend_url = "http://localhost:8080"
+            self.frontend_url = "http://host.docker.internal:8080"
         else:
             self.frontend_url = "https://cakework-frontend.fly.dev"
 
     def RunActivity(self, request, context):
+        print("local mode is: " + str(self.local))
+        print("frontend url: " + self.frontend_url)
         print("got request")
         print(request)
-
+        print("after printing request")
         # update to in progress
         response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": request.userId, "app": request.app, "requestId": request.requestId, "status": "IN_PROGRESS"})
         print("updated status to IN_PROGRESS") # this may be a lie
         # TODO check the response
-        print("before json.loads")
         parameters = json.loads(request.parameters)
-        print("before spawning thread")
         task = threading.Thread(target=self.background, args=[request.userId, request.app, request.requestId, parameters])
         task.daemon = True # Q: does returning kill the task?
-        print("starting background task")
         task.start()
-        print("started background task")
         # what should we return? now, the client is no longer hitting the grpc server
         return cakework_pb2.Reply(result=json.dumps("worker started task")) # TODO this should return the request id
 
     # note: we need to get the request id in here as well
     def background(self, user_id, app, request_id, parameters):
 
-        print("starting background task with parameters: " + str(parameters))
+        # print("starting background task with parameters: " + str(parameters))
         try:
             res = self.user_activity(**parameters)
             print("finished task")
