@@ -43,8 +43,14 @@ class Client:
 
     def __getattr__(self, name):
         def method(**args):
+            print("inside __get_attr")
             sanitized_name = name.lower()
-            sanitized_name = name.replace('_', '-')                
+            sanitized_name = name.replace('_', '-')          
+            print(self.user_id)
+            print(self.app)
+            print(sanitized_name)
+            print(args)
+            # print(json.dumps(args))      
             response = requests.post(f"{self.frontend_url}/submit-task", json={"userId": self.user_id, "app": self.app, "task": sanitized_name, "parameters": json.dumps(args)})
             print(response) # TODO get rid of this logging
             response_json = response.json()
